@@ -2,10 +2,11 @@ from typing import Optional, Sequence, Union, List
 from pydantic import BaseModel
 
 from nav_dcat.fields import common_fields
+from nav_dcat.models.dataset import DatasetDocument
 
 
 class DataproductDocument(BaseModel):
-    title: Optional[str] = ""
+    title: str
     description: Optional[str] = ""
     uri: Optional[str] = ""
     modified: Optional[str] = None
@@ -29,5 +30,4 @@ class DataproductDocument(BaseModel):
     rights: Optional[str] = None
     content: Optional[dict] = {}
     url: Optional[str] = ""
-    resources: Optional[List[dict]] = []
-    views: Optional[List[dict]] = []
+    datasets: Optional[List[DatasetDocument]] = []
